@@ -16,6 +16,7 @@
 
 #include <NetworkManagerQt/GenericDevice>
 #include <NetworkManagerQt/Settings>
+#include <NetworkManagerQt/Manager>
 
 NetworkModel::NetworkModel(QObject *parent)
     : QAbstractListModel(parent)
@@ -35,8 +36,8 @@ QVariant NetworkModel::data(const QModelIndex &index, int role) const
         NetworkModelItem *item = m_list.itemAt(row);
 
         switch (role) {
-        case ConnectionDetailsRole:
-            return item->details();
+        case ConnectionDetailsModelRole:
+            return QVariant::fromValue(item->detailsModel());
         case ConnectionIconRole:
             return item->icon();
         case ConnectionPathRole:
@@ -130,7 +131,7 @@ int NetworkModel::rowCount(const QModelIndex &parent) const
 QHash<int, QByteArray> NetworkModel::roleNames() const
 {
     QHash<int, QByteArray> roles = QAbstractListModel::roleNames();
-    roles[ConnectionDetailsRole] = "ConnectionDetails";
+    roles[ConnectionDetailsModelRole] = "ConnectionDetailsModel";
     roles[ConnectionIconRole] = "ConnectionIcon";
     roles[ConnectionPathRole] = "ConnectionPath";
     roles[ConnectionStateRole] = "ConnectionState";
@@ -202,7 +203,7 @@ void NetworkModel::initialize()
 {
     // Initialize existing connections
     for (const NetworkManager::Connection::Ptr &connection : NetworkManager::listConnections()) {
-        addConnection(connection);
+        addConnection(connection, nullptr);
     }
 
     // Initialize existing devices
@@ -438,7 +439,7 @@ void NetworkModel::addAvailableConnection(const QString &connection, const Netwo
     }
 }
 
-void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connection)
+void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connection, const NetworkManager::Device::Ptr &device)
 {
     // Can't add a connection without name or uuid
     if (connection->name().isEmpty() || connection->uuid().isEmpty()) {
@@ -462,7 +463,7 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connecti
         return;
     }
 
-    auto item = new NetworkModelItem();
+    auto item = new NetworkModelItem(this);
     item->setConnectionPath(connection->path());
     item->setName(settings->id());
     item->setTimestamp(settings->timestamp());
@@ -470,6 +471,16 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connecti
     item->setUuid(settings->uuid());
     item->setSlave(settings->isSlave());
 
+    // Set device info if device is provided
+    if (device) {
+        if (device->ipInterfaceName().isEmpty()) {
+            item->setDeviceName(device->interfaceName());
+        } else {
+            item->setDeviceName(device->ipInterfaceName());
+        }
+        item->setDevicePath(device->uni());
+    }
+
     if (item->type() == NetworkManager::ConnectionSettings::Vpn) {
         item->setVpnType(vpnSetting->serviceType().section('.', -1));
     } else if (item->type() == NetworkManager::ConnectionSettings::Wireless) {
@@ -478,7 +489,7 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connecti
         item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
     }
 
-    item->invalidateDetails();
+    item->updateConnectionDetailsModel();
 
     insertItem(item);
     qCDebug(PLASMA_NM_LIBS_LOG) << "New connection" << item->name() << "added";
@@ -574,7 +585,7 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
     item->setSsid(network->ssid());
     item->setType(NetworkManager::ConnectionSettings::Wireless);
     item->setSecurityType(securityType);
-    item->invalidateDetails();
+    item->updateConnectionDetailsModel();
 
     insertItem(item);
     qCDebug(PLASMA_NM_LIBS_LOG) << "New wireless network" << item->name() << "added";
@@ -598,7 +609,7 @@ void NetworkModel::checkAndCreateDuplicate(const QString &connection, const QStr
 
     if (createDuplicate) {
         auto duplicatedItem = new NetworkModelItem(originalItem);
-        duplicatedItem->invalidateDetails();
+        duplicatedItem->updateConnectionDetailsModel();
 
         insertItem(duplicatedItem);
     }
@@ -661,9 +672,26 @@ void NetworkModel::updateItem(NetworkModelItem *item)
 
     const int row = m_list.indexOf(item);
     if (row != -1) {
-        item->invalidateDetails();
+        const auto changedRoles = item->changedRoles();
+        bool detailsChanged = false;
+
+        if (changedRoles.isEmpty()) { // any/unknown roles changed
+            detailsChanged = true;
+        } else {
+            auto detailsChangedRoles = changedRoles;
+            // Ignore roles that are not relevant for the details model.
+            detailsChangedRoles.removeOne(ItemRole::ConnectionIconRole);
+            detailsChangedRoles.removeOne(ItemRole::TxBytesRole);
+            detailsChangedRoles.removeOne(ItemRole::RxBytesRole);
+            detailsChanged = !detailsChangedRoles.isEmpty();
+        }
+
+        if (detailsChanged) {
+            item->updateConnectionDetailsModel();
+        }
+
         QModelIndex index = createIndex(row, 0);
-        Q_EMIT dataChanged(index, index, item->changedRoles());
+        Q_EMIT dataChanged(index, index, changedRoles);
         item->clearChangedRoles();
         updateDelayModelUpdates();
     }
