@@ -27,7 +27,7 @@ public:
     void loadConfig(const NetworkManager::VpnSetting::Ptr &setting);
 
 private:
-    Ui::VpncAdvancedWidget *m_ui;
+    Ui::VpncAdvancedWidget *const m_ui;
 };
 
 #endif // PLASMA_NM_VPNC_ADVANCED_WIDGET_H
